/* This is the profile tester.  This is compiled as normal C
 * The code in profile-testee.c is compiled through the profiler.
 * This code calls that code.
 */
#include <assert.h>
#include <stdio.h>
#include "profile-testee.h"

struct s_bit s_bit_v;

enum {ELEN = 9999};
struct expect_s {
    int iswrite;
    void const* addr;
    unsigned len;
} expect_data[ELEN];
int n_expect=0, n_saw=0;
void clear (void) {
    n_expect=0;
    n_saw=0;
}
void finish(void) {
    assert(n_expect==n_saw);
}
void expect (int iswrite, const void *const addr, unsigned len) {
    assert(n_expect<ELEN);
    //printf("expect(%d, %p, %d);\n", iswrite, addr, len);
    expect_data[n_expect].iswrite = iswrite; 
    expect_data[n_expect].addr    = addr;
    expect_data[n_expect].len     = len;
    n_expect++;
}
void checkit (int iswrite, const void *const addr, unsigned len) {
    //printf("checkit(%d, %p, %d);\n", iswrite, addr, len);
    assert(n_saw<n_expect);
    assert(expect_data[n_saw].iswrite==iswrite);
    assert(expect_data[n_saw].addr   ==addr);
    assert(expect_data[n_saw].len    ==len);
    n_saw++;
}

void __c2c_ProfileRead(const void*const addr,unsigned len,const char*file __attribute__((__unused__)),unsigned line __attribute__((__unused__))) {
    checkit(0, addr, len);
}
void __c2c_ProfileWrite(const void*const addr,unsigned len,const char*file __attribute__((__unused__)),unsigned line __attribute__((__unused__))) {
    checkit(1, addr, len);
}

struct s_bit s_e, s_a[10];
struct ss_s ss_v, ss_a[10];

struct s_bit s_e_value (void) {
    return s_e;
}

int main (int argc, char *argv[] __attribute__((__unused__))) {
    int r;
    assert(argc==1);

    s_bit_v.a = 0;

    clear();
    expect(1, &s_bit_v, sizeof(s_bit_v));
    expect(0, &s_bit_v, sizeof(s_bit_v));
    r=prof_BsP(&s_bit_v);
    finish();
    assert(r==1);

    clear();
    expect(1, &s_e, sizeof(s_e));
    expect(1, &s_a[5], sizeof(s_a[5]));
    expect(0, &s_e, sizeof(s_e));
    expect(0, &s_a[5], sizeof(s_a[5]));
    r=prof_Bsp();
    finish();
    assert(r==2);

    clear();
    expect(1, &s_e.b, sizeof(s_e.b));
    expect(1, &s_a[5].b, sizeof(s_a[5].b));
    expect(0, &s_e.b, sizeof(s_e.b));
    expect(0, &s_a[5].b, sizeof(s_a[5].b));
    r=prof_bs();
    finish();
    assert(r==35);

    clear();
    expect(1, &s_a[5].b, sizeof(s_a[5].b));
    expect(0, &s_a[5].b, sizeof(s_a[5].b));
    r=prof_bS();
    finish();
    assert(r==28);

    clear();
    expect(1, &s_a[5], sizeof(s_a[5]));
    expect(0, &s_a[5], sizeof(s_a[5]));
    r=prof_BS();
    finish();
    assert(r==6);
   
    clear();
    expect(1, &ss_v.s, sizeof(ss_v.s));
    expect(1, &ss_v.s.b, sizeof(ss_v.s.b));
    expect(1, &ss_a[5].s, sizeof(ss_a[5].s));
    expect(1, &ss_a[5].s.b, sizeof(ss_a[5].s.b));
    expect(0, &ss_v.s, sizeof(ss_v.s));
    expect(0, &ss_v.s.b, sizeof(ss_v.s.b));
    expect(0, &ss_a[5].s, sizeof(ss_a[5].s));
    expect(0, &ss_a[5].s.b, sizeof(ss_a[5].s.b));
    r=prof_nested();
    finish();
    assert(r==6);

    s_e.b=923;
    clear(); // No expected values.
    r=prof_no_mem();
    finish();    
    assert(r==923+4);

    return 0;
}
